Element Reference

# XMLRésuméLibrary: User Guide

Part II. Reference | Part II. Reference | academics

# Element Reference

XML Résumé files are XML files composed mostly of elements. This part of the user guide documents the semantics (meaning) and syntax (structure) of all of the elements that you can use to construct a résumé.

To get started with creating a résumé, take a look Chapter 2, which is a tutorial on creating an XML résumé. Alternatively, you could examine the content model for the `resume` element, and drill down from there.

## Changes to the DTD

This sections documents changes to the XML Résumé Library DTD.

### Warning

Deprecated elements will still be formatted, and are still valid elements in an XML résumé. However, their use is discouraged, and they will be removed in a future version of the DTD.

### Version ???

- Changed elements: `projects` may now be included in the `degree` element.

### Version 1.5.0

- Changed elements: `date` can now be used in place of `period` in `membership` and `job`.

- Changed elements: `period` can be used in place of `date` in `award` and `clearance`.

- Changed element: `major` is no longer a required child of `degree`.

- Changed element: The `project` element now supports an optional `title` attribute.

### Version 1.4.2

No DTD changes.

### Version 1.4.1

- New elements: `clearances` and `clearance`.

- New elements: `gpa`, `score`, and `possible`.

- New element: `location`. It may be contained in `job`, `degree`, or `membership`.

- Change: `name` may now contain a `title`.

- Change: `institution` and `organization` may now contain inline elements (`emphasis`, `citation`, `url`, and `link`).

### Version 1.4.0

- New element: `minor`.

- New element: `lastModified`.

- New elements: `awards` and `award`.

- New elements: `interests` and `interest`.

- New elements: `fax`, `pager`, and `instantMessage`. These may be contained in `contact`.

- New attribute: the `phone` element now has a `location` attribute.

- New attribute: the `skill` element now has a `level` attribute.

- Change: the `degree` element may now contain multiple `major` elements.

- Change: the `pub` element may now contain a `url` element.

- Change: the `contact` element may now contain any number of its allowed child elements, and they may appear in any order.

- Change: the `resume` element may now directly contain`skillarea` elements.

- Change: the `skillset` element may now directly contain `skill` elements.

- Change: the `degree` element may now contain either a `period` or a `date` element. It could previously contain only a `date`.

- Change: the `artTitle` and The `bookTitle` elements may now contain `link` elements.

- Change: the `referee` element may now contain an optional `title` element and an optional `organization` element.

- Change: the `month` element is no longer required in the `date` element. (However, it must appear if the `date` contains a `dayOfMonth` element.)

- Deprecated element: `skillareas`. You may simply remove the start and end tags from your résumé.

- Deprecated element: `skills`. You may simply remove the start and end tags from your résumé.

- Deprecated element: `pubDate`. Replace it with a `date` element.

- Deprecated elements: `docpath`, `head`, `node`, `tail`, `label`, and `uri`. Instances of these elements should be removed.

### Version 1.3.3

- New element: `link`.

- New attribute: the `address` element now has an optional `format` attribute.

- New attributes: Added namespace support. More specifically, added `xmlns`, `xmlns:xsi`, and `xsi:schemaLocation` attributes to the `resumes` and `resume` elements.

- Change: `employer` may now contain inline elements (`emphasis`, `citation`, `url`, and `link`).

- Deprecated element: `break`. Instances of this element should be removed.

- Deprecated element: `company`. Instances of this element should be removed.

- Deprecated element: `street2`. These elements should be converted to `street` elements.

### Version 1.3.2

No DTD changes.

Part II. Reference | Part II. Reference | academics